@@ -107,6 +107,7 @@
 #define ATTR_u "User_List"
 #define ATTR_v "Variable_List"
 #define ATTR_A "Account_Name"
+#define ATTR_args "job_arguments"
 #define ATTR_M "Mail_Users"
 #define ATTR_N "Job_Name"
 #define ATTR_S "Shell_Path_List"
@@ -164,11 +165,17 @@
 #define ATTR_intcmd      "inter_cmd"
 #define ATTR_P           "proxy_user"
 #define ATTR_exec_gpus   "exec_gpus"
+#define ATTR_J           "job_id"
 
 #ifdef USEJOBCREATE
 #define ATTR_pagg         "pagg_id"
 #endif /* USEJOBCREATE */
 
+#ifdef NVIDIA_GPUS
+  /* JOB_ATR_gpu_flags */
+#define ATTR_gpu_flags		"gpu_flags"
+#endif  /* NVIDIA_GPUS */
+
 /* additional queue attributes names */
 
 #define ATTR_aclgren    "acl_group_enable"
@@ -299,6 +306,7 @@
 #define ATTR_NODE_status        "status"
 #define ATTR_NODE_note          "note"
 #define ATTR_NODE_gpus           "gpus"
+#define ATTR_NODE_gpustatus      "gpu_status"
 
 /* notification email formating */
 #define ATTR_mailsubjectfmt "mail_subject_fmt"
@@ -314,15 +322,16 @@
 #define MAIL_AT_ABORT "a"
 
 
-#define ARRAY_RANGE "array_range=" /* see qdel.c */
-#define DELDELAY  "deldelay=" /* see qdel.c */
-#define DELPURGE  "delpurge="   /* see qdel.c */
-#define PURGECOMP  "purgecomplete="   /* see req_delete.c */
-#define EXECQUEONLY  "exec_queue_only"   /* see req_stat.c */
+#define ARRAY_RANGE "array_range="      /* see qdel.c */
+#define DELDELAY  "deldelay="           /* see qdel.c */
+#define DELPURGE  "delpurge="           /* see qdel.c */
+#define DELASYNC  "delasync"            /* see qdel.c */
+#define PURGECOMP  "purgecomplete="     /* see req_delete.c */
+#define EXECQUEONLY  "exec_queue_only"  /* see req_stat.c */
 #define RERUNFORCE "force"
 
-#define USER_HOLD "u"
-#define OTHER_HOLD "o"
+#define USER_HOLD   "u"
+#define OTHER_HOLD  "o"
 #define SYSTEM_HOLD "s"
 
 /* node-attribute values (state,ntype) */
@@ -397,6 +406,7 @@
 
 #define PBS_MAXUSER  32 /* max user name length */
 #define PBS_MAXGRPN  16 /* max group name length */
+#define PBS_MAXGPUID 16 /* max gpu id length */
 #define PBS_MAXQUEUENAME 15 /* max queue name length */
 #define PBS_MAXSERVERNAME PBS_MAXHOSTNAME /* max server name length */
 #define PBS_MAXJOBARRAYLEN      7       /* number of characters allowed in jobarray portion of job id, including '[]' */
@@ -414,8 +424,8 @@
 
 #define PBS_MAXCREDENTIAL_LEN 2048 /* Maximum authentication credential length. */
 /* constants used to indicate version of job ji_qs struct written to disk.
-   starting with 2.4.0 we stopped encoding the torque version number into the 
-   hex value e.g. 0x00020300 for torque v2.3.0. Now we just increment a value 
+   starting with 2.4.0 we stopped encoding the torque version number into the
+   hex value e.g. 0x00020300 for torque v2.3.0. Now we just increment a value
    which is added to the last version encoded that way */
 #define PBS_QS_VERSION_BASE 0x00020300 /* magic number do not change */
 #define PBS_QS_VERSION_INT 2 /* increment this version number with every change to the ji_qs struct */
@@ -607,6 +617,8 @@ extern int
 extern int
   usepool(int connect, int update);
 
+extern int pbs_gpumode(int connect, char *node, char *gpuid, int gpumode);
+
 #endif /* _PBS_IFL_DEF */
 
 /*  end of pbs_ifl.h  */
