@@ -334,6 +334,11 @@ enum job_atr
 #ifdef USEJOBCREATE
   JOB_ATR_pagg_id,
 #endif /* USEJOBCREATE */
+  JOB_ATR_job_id,
+#ifdef NVIDIA_GPUS
+  JOB_ATR_gpu_flags,		/* gpu flags - mode and reset flags */
+#endif  /* NVIDIA_GPUS */
+  JOB_ATR_arguments,
 #include "site_job_attr_enum.h"
 
   JOB_ATR_UNKN,  /* the special "unknown" type    */
@@ -690,6 +695,27 @@ typedef struct infoent
   list_link ie_next; /* link to next one */
   } infoent;
 
+
+
+
+
+#ifdef PBS_MOM
+typedef struct job_file_delete_info
+  {
+  char           jobid[PBS_MAXSVRJOBID+1];
+  char           prefix[PBS_JOBBASE + 1];
+  char          *checkpoint_dir;
+  unsigned char  has_temp_dir;
+  unsigned char  has_node_file;
+  gid_t          gid;
+  uid_t          uid;
+  } job_file_delete_info;
+#endif
+
+
+
+
+
 #define TI_FLAGS_INIT           1  /* task has called tm_init */
 #define TI_FLAGS_CHECKPOINT     2  /* task has checkpointed */
 
@@ -888,6 +914,7 @@ dir so that job can be restarted */
 #define JOB_EXEC_BADRESRT -7 /* job restart failed */
 #define JOB_EXEC_CMDFAIL  -8 /* exec() of user command failed */
 #define JOB_EXEC_STDOUTFAIL -9 /* could not create/open stdout stderr files */
+#define JOB_EXEC_OVERLIMIT      -10 /* job aborted after successful start */
 
 extern void  add_dest(job *);
 extern void  depend_clrrdy(job *);
