@@ -448,6 +448,7 @@ static int set_allacl(struct attribute *attr, struct attribute *new, enum batch_
           return (PBSE_SYSTEM);
           }
 
+        memset(pas->as_buf, 0, nsize);
         pas->as_bufsize = nsize;
 
         }
@@ -460,6 +461,7 @@ static int set_allacl(struct attribute *attr, struct attribute *new, enum batch_
 
       /* No break, "Set" falls into "Incr" to add strings */
 
+    case INCR_OLD:
     case INCR:
 
       /* check for duplicates within new and between new and old  */
