@@ -359,8 +359,9 @@ static char *PBS_get_server(
  * a user connection with the server. 
  */
 #ifdef MUNGE_AUTH
-static int PBSD_munge_authenticate(
-  int psock) /* I */
+int PBSD_munge_authenticate(
+  int psock, /* I */
+  int handle) /* I */
   {
   int fd_pipe[2];
 
@@ -452,7 +453,7 @@ static int PBSD_munge_authenticate(
       rc = DIS_tcp_wflush(psock);
 
       /* read the reply */
-      reply = PBSD_rdrpy(1);
+      reply = PBSD_rdrpy(handle);
     }
   else
     {
@@ -480,7 +481,7 @@ static int PBSD_munge_authenticate(
  */
 
 #ifndef MUNGE_AUTH
-static int PBSD_authenticate(
+int PBSD_authenticate(
 
   int psock)  /* I */
 
@@ -491,6 +492,8 @@ static int PBSD_authenticate(
   int    j;
   FILE *piff;
   char  *ptr;
+  char  *path_copy;
+  char  *token;
 
   struct stat buf;
 
@@ -522,18 +525,26 @@ static int PBSD_authenticate(
         {
         ptr = strtok(ptr, ":");
 
-        while (ptr != NULL)
+        if ((path_copy = strdup(ptr)) == NULL)
           {
-          snprintf(iffpath, sizeof(iffpath), "%s/pbs_iff",
-                   ptr);
+          fprintf(stderr,"Cannot allocate memory, FAILURE");
+
+          return(-1);
+          }
+
+        token = strtok(path_copy, ":");
+
+        while (token != NULL)
+          {
+          snprintf(iffpath, sizeof(iffpath), "%s/pbs_iff", token);
 
           rc = stat(iffpath, &buf);
 
           if (rc != -1)
             break;
 
-          ptr = strtok(NULL, ":");
-          }  /* END while (ptr != NULL) */
+          token = strtok(NULL, ":");
+          }  /* END while (token != NULL) */
         }    /* END if ((ptr = getenv("PATH")) != NULL) */
 
       if (rc == -1)
@@ -939,7 +950,7 @@ int pbs_original_connect(
 #endif
 
 #ifdef MUNGE_AUTH
-    auth = PBSD_munge_authenticate(connection[out].ch_socket);
+    auth = PBSD_munge_authenticate(connection[out].ch_socket, out);
     if(auth != 0)
       {
       close(connection[out].ch_socket);
@@ -1039,7 +1050,7 @@ int pbs_disconnect(
 
   {
   int  sock;
-  static char x[THE_BUF_SIZE / 4];
+  int  rc;
 
   /* send close-connection message */
 
@@ -1047,42 +1058,18 @@ int pbs_disconnect(
 
   DIS_tcp_setup(sock);
 
-  if ((encode_DIS_ReqHdr(sock, PBS_BATCH_Disconnect, pbs_current_user) == 0) &&
-      (DIS_tcp_wflush(sock) == 0))
+  rc = encode_DIS_ReqHdr(sock, PBS_BATCH_Disconnect, pbs_current_user);
+  if(rc)
     {
-    int atime;
-
-    struct sigaction act;
-
-    struct sigaction oldact;
-
-    /* set alarm to break out of potentially infinite read */
-
-/*    act.sa_handler = SIG_IGN; */
-    act.sa_handler = empty_alarm_handler;  /* need SOME handler or blocking read never gets interrupted */
-
-    sigemptyset(&act.sa_mask);
-    act.sa_flags = 0;
-    sigaction(SIGALRM, &act, &oldact);
-
-    atime = alarm(pbs_tcp_timeout);
-
-    while (1)
-      {
-      /* wait for server to close connection */
-
-      /* NOTE:  if read of 'sock' is blocking, request below may hang forever
-         -- hence the signal handler above */
-
-      if (read(sock, &x, sizeof(x)) < 1)
-        break;
-      }
-
-    alarm(atime);
-
-    sigaction(SIGALRM, &oldact, NULL);
+    return(rc);
     }
 
+   rc = DIS_tcp_wflush(sock);
+   if(rc)
+     {
+     return(rc);
+     }
+    
   close(sock);
 
   if (connection[connect].ch_errtxt != (char *)NULL)
