@@ -436,7 +436,10 @@ scan_for_exiting(void)
         {
         /* master task is in state TI_STATE_EXITED */
 
-        pjob->ji_qs.ji_un.ji_momt.ji_exitstat = ptask->ti_qs.ti_exitstat;
+        if(pjob->ji_qs.ji_un.ji_momt.ji_exitstat != JOB_EXEC_OVERLIMIT)
+          {
+          pjob->ji_qs.ji_un.ji_momt.ji_exitstat = ptask->ti_qs.ti_exitstat;
+          }
 
         LOG_EVENT(
           PBSEVENT_JOB,
@@ -1977,12 +1980,6 @@ void init_abort_jobs(
 
   closedir(dir);
 
-#if defined(PENABLE_LINUX26_CPUSETS)
-  /* Create the top level torque cpuset if it doesn't already exist. */
-  initialize_root_cpuset();
-
-#endif
-
   return;
   }  /* END init_abort_jobs() */
 
