@@ -119,6 +119,7 @@
 #include "mom_mach.h"
 #include "mom_func.h"
 #include "resmon.h"
+#include "utils.h"
 #include "../rm_dep.h"
 
 
@@ -382,7 +383,7 @@ proc_stat_t *get_proc_stat(
 
   lastbracket++;
 
-  if (sscanf(readbuf,"%d (%[^\n]",&ps.pid,path) != 2) 
+  if (sscanf(readbuf,"%d (%[^\n]",&ps.pid,path) != 2)
     {
     /* FAILURE */
 
@@ -393,7 +394,7 @@ proc_stat_t *get_proc_stat(
 
   /* see stat_str[] value for mapping 'stat' format */
 
-  if (sscanf(lastbracket,stat_str, 
+  if (sscanf(lastbracket,stat_str,
         &ps.state,     /* state (one of RSDZTW) */
         &ps.ppid,      /* ppid */
         &ps.pgrp,      /* pgrp */
@@ -1422,7 +1423,7 @@ int mom_set_limits(
 #endif /* __GATECH */
 
           mem_limit = value;
-  
+
           if (getrlimit(RLIMIT_STACK, &reslim) >= 0)
             {
             /* NOTE:  mem_limit no longer used with UMU patch in place */
@@ -1916,7 +1917,7 @@ int mom_over_limit(
  * stats gathered by the mom_get_sample() function. This function
  * is often called by "im_request()" as a result of POLL_JOB query
  * from the mother superior.
- * 
+ *
  * @see im_request() - parent - respond to poll_job request from mother superior
  * @see examine_all_running_jobs() - parent - update local use on mother superior
  * @see TMomFinalizeJob1() - parent - update serial job immediately at job start
@@ -2069,12 +2070,12 @@ int mom_set_use(
  * Kill a task session.
  * Call with the task pointer and a signal number.
  *
- * @return number of tasks signalled (0 = failure) 
+ * @return number of tasks signalled (0 = failure)
  *
  * @see kill_job() - parent
  *
  * NOTE:  should support killpg() or killpidtree() - (NYI)
- *        may be required for suspend/resume 
+ *        may be required for suspend/resume
  */
 
 int kill_task(
@@ -2332,8 +2333,8 @@ int kill_task(
     }      /* END while ((dent = readdir(pdir)) != NULL) */
 
   /* NOTE:  to fix bad state situations resulting from a hard crash, the logic
-            below should be triggered any time no processes are found (NYI) */ 
-            
+            below should be triggered any time no processes are found (NYI) */
+
   if (IS_ADOPTED_TASK(ptask->ti_qs.ti_task) && (NumProcessesFound == 0))
     {
     /* no process was found, but for an adopted task this is OK (we don't find
@@ -3427,7 +3428,70 @@ static char *ncpus(
   return(ret_string);
   }  /* END ncpus() */
 
+/* find_file checks for the existence of filename
+ * in the ':' delimited path string
+ * Return TRUE if file exists
+ *        FALSE if file not found
+ */
 
+int find_file(char *path, char *filename)
+  {
+  char *ptr1, *ptr2;
+  char buf[RETURN_STRING_SIZE];
+
+  int rc;
+  struct stat statBuf;
+
+  if(path == NULL)
+    {
+    return(FALSE);
+    }
+
+  if(filename == NULL)
+    {
+    return(FALSE);
+    }
+
+  memset(buf, 0, RETURN_STRING_SIZE);
+  ptr1 = path;
+  ptr2 = buf;
+
+  do
+    {
+    *ptr2 = *ptr1;
+    ptr1++;
+
+    if(*ptr1 == ':' || *ptr1 == '\0')
+      {
+      /* check for the forward slash at the end of the path variable */
+      if(*ptr2 != '/')
+        {
+        ptr2++;
+        *ptr2 = '/';
+        }
+      strcat(buf, filename);
+
+      rc = stat(buf, &statBuf);
+      if(rc == 0)
+        {
+        return(TRUE);
+        }
+
+      /* Advance the pointer in the path */
+      ptr1++;
+      /* reset ptr2 to the beginning of buf and get the
+         next directory */
+      memset(buf, 0, RETURN_STRING_SIZE);
+      ptr2 = buf;
+      }
+    else
+      ptr2++; /* advance ptr2 to the next element in buf */
+
+    }while(*ptr1 != '\0');
+
+  return(FALSE);
+
+  }
 
 
 
@@ -3803,7 +3867,7 @@ void scan_non_child_tasks(void)
     }    /* END for (job = GET_NEXT(svr_alljobs)) */
 
   closedir(pdir);
-  
+
   first_time = FALSE;
 
   return;
@@ -4255,7 +4319,7 @@ static char *quota(
 
   if ((uid = (uid_t)atoi(attrib->a_value)) == 0)
     {
-    if ((pw = getpwnam(attrib->a_value)) == NULL)
+    if ((pw = getpwnam_ext(attrib->a_value)) == NULL)
       {
       sprintf(log_buffer,
               "user not found: %s", attrib->a_value);
