@@ -108,6 +108,7 @@
 
 /* Global Data Items: */
 
+extern char *server_name;
 extern struct connect_handle connection[];
 extern char     *msg_daemonname;
 extern tlist_head task_list_event;
@@ -264,7 +265,7 @@ int issue_to_svr(
   preq->rq_fromsvr = 1;
   preq->rq_perm = ATR_DFLAG_MGRD | ATR_DFLAG_MGWR | ATR_DFLAG_SvWR;
 
-  svrname = parse_servername(servern, &port);
+  svrname = parse_servername(servern, &port); 
   svraddr = get_hostaddr(svrname);
 
   if (svraddr == (pbs_net_t)0)
@@ -481,6 +482,19 @@ int issue_Drequest(
 
       break;
 
+    case PBS_BATCH_GpuCtrl:
+
+      rc = PBSD_gpu_put(
+             conn,
+             request->rq_ind.rq_gpuctrl.rq_momnode,
+             request->rq_ind.rq_gpuctrl.rq_gpuid,
+             request->rq_ind.rq_gpuctrl.rq_gpumode,
+             request->rq_ind.rq_gpuctrl.rq_reset_perm,
+             request->rq_ind.rq_gpuctrl.rq_reset_vol,
+             NULL);
+
+      break;
+
     case PBS_BATCH_MessJob:
 
       rc = PBSD_msg_put(
