@@ -257,6 +257,7 @@ int   server_init_type = RECOV_WARM;
 char         server_name[PBS_MAXSERVERNAME + 1]; /* host_name[:service|port] */
 int  svr_delay_entry = 0;
 int  svr_do_schedule = SCH_SCHEDULE_NULL;
+extern int  listener_command;
 tlist_head svr_queues;            /* list of queues                   */
 tlist_head svr_alljobs;           /* list of all jobs in server       */
 tlist_head svr_jobs_array_sum;    /* list of jobs in server, arrays summarized as single "placeholder" job */
@@ -474,6 +475,7 @@ clear_listeners(void)   /* I */
     listener_conns[i].address = 0;
     listener_conns[i].port = 0;
     listener_conns[i].sock = -1;
+    listener_conns[i].first_time = 1;
     }
 
   return;
@@ -755,6 +757,8 @@ void parse_command_line(int argc, char *argv[])
 
       case 'l':
 
+        clear_listeners();
+
         if (get_port(
               optarg,
               &listener_port,
@@ -980,7 +984,10 @@ static time_t next_task()
   /* should the scheduler be run?  If so, adjust the delay time  */
 
   if ((delay = server.sv_next_schedule - time_now) <= 0)
+    {
     svr_do_schedule = SCH_SCHEDULE_TIME;
+    listener_command = SCH_SCHEDULE_TIME;
+    }
   else if (delay < tilwhen)
     tilwhen = delay;
 
@@ -1120,7 +1127,7 @@ main_loop(void)
     else
       waittime = next_task();
 
-    waittime = MAX(0, waittime);
+    waittime = MAX(1, waittime);
 
     if (*state == SV_STATE_RUN)
       {
@@ -1629,7 +1636,6 @@ int main(
     log_buffer);
 
 
-
   /* initialize the server objects and perform specified recovery */
   /* will be left in the server's private directory  */
   /* NOTE:  env cleared in pbsd_init() */
@@ -2035,7 +2041,7 @@ char *extract_dir(
 
   Dir[0] = '\0';
 
-  snprintf(Dir,sizeof(Dir),"%s",FullPath);
+  snprintf(Dir, DirSize,"%s",FullPath);
 
   ptr = strrchr(Dir,'/');
 
@@ -2067,12 +2073,12 @@ int is_ha_lock_file_valid(
   struct stat Stat;
   bool_t      GoodPermissions = FALSE;
 
-  if (HALockFile[0] == '\0')
+  if (lockfile[0] == '\0')
     {
     return(FALSE);
     }
 
-  extract_dir(HALockFile,LockDir,sizeof(LockDir));
+  extract_dir(lockfile, LockDir, sizeof(LockDir));
 
   if (stat(LockDir,&Stat) != 0)
     {
@@ -2535,10 +2541,7 @@ static void lock_out_ha()
 
     NumChecks++;
 
-    if (is_ha_lock_file_valid(HALockFile) == FALSE)
-      {
-      UseFLock = TRUE;
-      }
+    UseFLock = is_ha_lock_file_valid(HALockFile);
 
     if (UseFLock == TRUE)
       {
