@@ -125,11 +125,13 @@ extern char *msg_job_end_sig;
 extern char *msg_job_end_stat;
 extern char *msg_momnoexec1;
 extern char *msg_momnoexec2;
+extern char *msg_momjoboverlimit;
 extern char *msg_obitnojob;
 extern char *msg_obitnocpy;
 extern char *msg_obitnodel;
 extern char  server_host[];
 extern int   svr_do_schedule;
+extern int   listener_command;
 extern time_t time_now;
 
 extern int   LOGLEVEL;
@@ -703,6 +705,7 @@ void rel_resc(
   /* mark that scheduler should be called */
 
   svr_do_schedule = SCH_SCHEDULE_TERM;
+  listener_command = SCH_SCHEDULE_TERM;
 
   return;
   }  /* END rel_resc() */
@@ -735,9 +738,7 @@ void on_job_exit(
   {
   int    handle = -1;
   job   *pjob;
-#ifdef VNODETESTING
   job   *pj;
-#endif
 
   struct batch_request *preq;
 
@@ -766,9 +767,7 @@ void on_job_exit(
     pjob = (job *)preq->rq_extra;
     }
 
-#ifdef VNODETESTING
-  /* FIXME: there might be a race with calling on_job_exit after a job has
-   * already been free'd.  This is temp code */
+  /* make sure the job is actually still there */
 
   pj = (job *)GET_NEXT(svr_alljobs);
 
@@ -780,29 +779,25 @@ void on_job_exit(
     pj = (job *)GET_NEXT(pj->ji_alljobs);
     }
 
+  /* if the job doesn't exist, just exit */
   if (pj == NULL)
     {
     sprintf(log_buffer, "on_job_exit called with INVALID pjob: %p",
-            pjob);
+            (void *)pjob);
+  
+    log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,"NULL",log_buffer);
+
+    return;
     }
   else
     {
     sprintf(log_buffer, "on_job_exit valid pjob: %p (substate=%d)",
-            pjob,
+            (void *)pjob,
             pjob->ji_qs.ji_substate);
+    
+    log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,"NULL",log_buffer);
     }
 
-  log_event(
-
-    PBSEVENT_JOB,
-    PBS_EVENTCLASS_JOB,
-    pjob->ji_qs.ji_jobid,
-    log_buffer);
-
-  DBPRT(("%s\n",
-         log_buffer));
-#endif /* END VNODETESTING */
-
   /*
    * we don't need a handle if we are complete. On starting up we will NOT have
    * a connection to mom, but still want to try and process the completed job
@@ -2039,6 +2034,10 @@ void on_job_rerun(
 
         job_attr_def[(int)JOB_ATR_session_id].at_free(
           &pjob->ji_wattr[(int)JOB_ATR_session_id]);
+
+        job_attr_def[(int)JOB_ATR_exec_gpus].at_free(
+          &pjob->ji_wattr[JOB_ATR_exec_gpus]);
+
         }
 
       pjob->ji_modified = 1; /* force full job save */
@@ -2462,6 +2461,13 @@ void req_jobobit(
     switch (exitstatus)
       {
 
+      case JOB_EXEC_OVERLIMIT:
+        /* the job exceeded some resource limit such as walltime, mem, pmem, cput, etc */
+        svr_mailowner(pjob, MAIL_ABORT, MAIL_FORCE, msg_momjoboverlimit);
+        alreadymailed = 1;
+
+        break;
+
       case JOB_EXEC_FAIL1:
 
       default:
