@@ -97,7 +97,7 @@
 #include "server.h"
 #include "credential.h"
 #include "batch_request.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "work_task.h"
 #include "tracking.h"
 #include "pbs_error.h"
@@ -107,6 +107,7 @@
 
 extern struct server server;
 extern char   server_name[];
+extern int    LOGLEVEL;
 
 /*
  * req_locatejob - service the Locate Job Request
@@ -158,6 +159,15 @@ void req_locatejob(
     }
   else
     {
+    if (LOGLEVEL >= 7)
+      {
+      log_event(
+        PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        preq->rq_ind.rq_locate,
+        "cannot find job in server tracking list");
+      }
+
     req_reject(PBSE_UNKJOBID, 0, preq, NULL, NULL);
     }
 
