@@ -187,7 +187,58 @@ static int user_account_read_user(char *);
 
 static char *pbs_o_que = "PBS_O_QUEUE=";
 
+/****************************************************************** 
+ * set_nodes_attr - Check to see is the node resource was requested
+ *                 on the qsub line. If not add the node attribute
+ *                 to the Resource_List and set the value to 1. This
+ *                 makes it so that if  procct is set on a queue
+ *                 jobs without a node resource request will still
+ *                 be properly routed.
+ * Returns: 0 if OK 
+ *          Non-Zero on failure 
+ *****************************************************************/
 
+int set_nodes_attr(job *pjob)
+  {
+  resource *pres;
+	int  nodect_set = 0;
+  int  rc = 0;
+  char *pname;
+
+  if(pjob->ji_wattr[JOB_ATR_resource].at_flags & ATR_VFLAG_SET)
+    {
+    pres = (resource *)GET_NEXT(pjob->ji_wattr[JOB_ATR_resource].at_val.at_list);
+    while(pres != NULL)
+      {
+      if(pres->rs_defin != NULL)
+        {
+        pname = pres->rs_defin->rs_name;
+        if(pname == NULL || *pname == 0)
+          {
+          pres = (resource *)GET_NEXT(pres->rs_link);
+          continue;
+          }
+        
+        if(strncmp(pname, "nodes", 5) == 0 
+          || strncmp(pname, "procs", 5) == 0)
+          {
+          nodect_set = 1;
+          break;
+          }
+        }
+        pres = (resource *)GET_NEXT(pres->rs_link);
+      }
+    }                                                                         
+
+    if(nodect_set == 0)
+      {
+      /* neither procs nor nodes were requested. set nodes to 1
+         so the procct will process correctly. */
+      rc = decode_resc(&pjob->ji_wattr[JOB_ATR_resource], ATTR_l, "nodes", "1");
+     }
+
+  return(rc);
+  }   /* END set_nodes_attr() */
 
 
 /*
@@ -222,6 +273,7 @@ void req_quejob(
   pbs_queue *pque;
   char  *qname;
   attribute  tempattr;
+  struct stat stat_buf;
   char           EMsg[1024];
 
   /* set basic (user) level access permission */
@@ -256,6 +308,7 @@ void req_quejob(
     }
   else
     {
+    /* Create a job id */
     char host_server[PBS_MAXSERVERNAME + 1];
     int  server_suffix = TRUE;
 
@@ -484,16 +537,15 @@ void req_quejob(
 
   while (psatl != NULL)
     {
-
-    if(psatl->al_atopl.resource)
+    if (psatl->al_atopl.resource)
       {
-      if(strcmp(psatl->al_atopl.resource, "nodes") == 0)
+      if (strcmp(psatl->al_atopl.resource, "nodes") == 0)
         {
         pj->ji_have_nodes_request = 1;
         }
       }
-    /* identify the attribute by name */
 
+    /* identify the attribute by name */
     attr_index = find_attr(job_attr_def, psatl->al_name, JOB_ATR_LAST);
 
     if (attr_index < 0)
@@ -564,15 +616,27 @@ void req_quejob(
       }    /* END if (rc != 0) */
 
     psatl = (svrattrl *)GET_NEXT(psatl->al_link);
-    }      /* END while (psatl != NULL) */
+    } /* END while (psatl != NULL) */
 
+  rc = set_nodes_attr(pj);
+  if(rc)
+    {
+    /* just record that we could not set node count */
+    sprintf(log_buffer, "Could not set default node count. Error not fatal. Will continue submitting job: %d",
+            rc);
+    LOG_EVENT(PBSEVENT_JOB,
+              PBS_EVENTCLASS_JOB,
+              id,
+              log_buffer);
+    }
+  
   /* perform any at_action routine declared for the attributes */
-
-  for (i = 0;i < JOB_ATR_LAST;++i)
+  for (i = 0; i < JOB_ATR_LAST; ++i)
     {
     pdef = &job_attr_def[i];
 
-    if ((pj->ji_wattr[i].at_flags & ATR_VFLAG_SET) && (pdef->at_action))
+    if ((pj->ji_wattr[i].at_flags & ATR_VFLAG_SET) && 
+        (pdef->at_action))
       {
       rc = pdef->at_action(&pj->ji_wattr[i], pj, ATR_ACTION_NEW);
 
@@ -587,6 +651,7 @@ void req_quejob(
       }
     }    /* END for (i) */
 
+
   /*
    * Now that the attributes have been decoded, we can setup some
    * additional parameters and perform a few more checks.
@@ -624,6 +689,41 @@ void req_quejob(
         }
       }
 
+    /* check if a job id was supplied, and if so overwrite the job id */
+    if (pj->ji_wattr[JOB_ATR_job_id].at_flags & ATR_VFLAG_SET)
+      {
+      char *dot = strchr(pj->ji_qs.ji_jobid,'.');
+      char  tmp_extension[PBS_MAXSVRJOBID + 1];
+      job  *tmpjob;
+
+      if (dot != NULL)
+        {
+        strcpy(tmp_extension,dot);
+
+        snprintf(pj->ji_qs.ji_jobid, sizeof(pj->ji_qs.ji_jobid),
+          "%s%s",
+          pj->ji_wattr[JOB_ATR_job_id].at_val.at_str,
+          tmp_extension);
+        }
+      else
+        {
+        strcpy(pj->ji_qs.ji_jobid,pj->ji_wattr[JOB_ATR_job_id].at_val.at_str);
+        }
+
+      if ((tmpjob = find_job(pj->ji_qs.ji_jobid)) != NULL)
+        {
+        /* not unique, reject job */
+        job_purge(pj);
+
+        snprintf(log_buffer,sizeof(log_buffer),
+          "Job with id %s already exists, cannot set job id\n",
+          pj->ji_qs.ji_jobid);
+        req_reject(PBSE_JOBEXIST,0,preq,NULL,log_buffer);
+
+        return;
+        }
+      }
+
     /* set job owner attribute to user@host */
 
     job_attr_def[JOB_ATR_job_owner].at_free(
@@ -716,6 +816,36 @@ void req_quejob(
           pj->ji_wattr[JOB_ATR_outpath].at_val.at_str,
           (int)'o')));
       }
+    else if (pj->ji_wattr[JOB_ATR_outpath].at_flags & ATR_VFLAG_SET)
+      {
+      /* check to see if the path pointed to is a directory. If so apendd the default output file name.
+         Otherwise we treat the string as a path to a file */
+      char *ptr;
+
+      ptr = strchr(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, ':');
+      if(ptr)
+        {
+        ptr++;
+        rc = stat(ptr, &stat_buf);
+        }
+      else 
+        {
+        rc = stat(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, &stat_buf);
+        }
+      if(rc == 0)
+        {
+        if(S_ISDIR(stat_buf.st_mode))
+          {
+/*          strcat(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, "/"); */
+          replace_attr_string(
+            &pj->ji_wattr[JOB_ATR_outpath],
+            (add_std_filename(pj,
+            pj->ji_wattr[JOB_ATR_outpath].at_val.at_str,
+            (int)'o')));
+      
+          }
+        }
+      }
 
     if (!(pj->ji_wattr[JOB_ATR_errpath].at_flags & ATR_VFLAG_SET) ||
         (((pj->ji_wattr[JOB_ATR_errpath].at_val.at_str[strlen(pj->ji_wattr[JOB_ATR_errpath].at_val.at_str) - 1] == ':'))))
@@ -740,6 +870,36 @@ void req_quejob(
           pj->ji_wattr[JOB_ATR_errpath].at_val.at_str,
           (int)'e')));
       }
+    else if (pj->ji_wattr[JOB_ATR_errpath].at_flags & ATR_VFLAG_SET)
+      {
+        /* check to see if the path pointed to is a directory. If so apendd the default output file name.
+           Otherwise we treat the string as a path to a file */
+      char *ptr;
+
+      ptr = strchr(pj->ji_wattr[JOB_ATR_errpath].at_val.at_str, ':');
+      if(ptr)
+        {
+        ptr++;
+        rc = stat(ptr, &stat_buf);
+        }
+      else 
+        {
+        rc = stat(pj->ji_wattr[JOB_ATR_errpath].at_val.at_str, &stat_buf);
+        }
+      if(rc == 0)
+        {
+        if(S_ISDIR(stat_buf.st_mode))
+          {
+/*          strcat(pj->ji_wattr[JOB_ATR_outpath].at_val.at_str, "/"); */
+          replace_attr_string(
+            &pj->ji_wattr[JOB_ATR_errpath],
+            (add_std_filename(pj,
+            pj->ji_wattr[JOB_ATR_errpath].at_val.at_str,
+            (int)'e')));
+      
+          }
+        }
+      }
 
     if ((pj->ji_wattr[JOB_ATR_outpath].at_val.at_str == NULL) ||
         (pj->ji_wattr[JOB_ATR_errpath].at_val.at_str == NULL))
@@ -1053,17 +1213,19 @@ void req_jobscript(
     {
     if (errno == 0)
       {
-      sprintf(log_buffer, "job %s in unexpected state '%s'",
-              pj->ji_qs.ji_jobid,
-              PJobSubState[pj->ji_qs.ji_substate]);
+      snprintf(log_buffer, sizeof(log_buffer),
+        "job %s in unexpected state '%s'",
+        pj->ji_qs.ji_jobid,
+        PJobSubState[pj->ji_qs.ji_substate]);
       }
     else
       {
-      sprintf(log_buffer, "job %s in unexpected state '%s' (errno=%d - %s)",
-              pj->ji_qs.ji_jobid,
-              PJobSubState[pj->ji_qs.ji_substate],
-              errno,
-              strerror(errno));
+      snprintf(log_buffer, sizeof(log_buffer),
+        "job %s in unexpected state '%s' (errno=%d - %s)",
+        pj->ji_qs.ji_jobid,
+        PJobSubState[pj->ji_qs.ji_substate],
+        errno,
+        strerror(errno));
       }
 
     log_err(errno, id, log_buffer);
@@ -1264,9 +1426,10 @@ void req_mvjobfile(  /* NOTE:  routine for server only - mom code follows this r
 
   if (LOGLEVEL >= 6)
     {
-    sprintf(log_buffer, "successfully moved file '%s' for job '%s'",
-            namebuf,
-            preq->rq_ind.rq_jobfile.rq_jobid);
+    snprintf(log_buffer, sizeof(log_buffer),
+      "successfully moved file '%s' for job '%s'",
+      namebuf,
+      preq->rq_ind.rq_jobfile.rq_jobid);
 
     log_record(
       PBSEVENT_JOB,
@@ -1382,9 +1545,10 @@ void req_rdytocommit(
     {
     char tmpLine[1024];
 
-    sprintf(tmpLine, "cannot save job - errno=%d - %s",
-            errno,
-            strerror(errno));
+    snprintf(tmpLine, sizeof(tmpLine),
+      "cannot save job - errno=%d - %s",
+      errno,
+      strerror(errno));
 
     log_err(errno, id, tmpLine);
 
@@ -1408,9 +1572,10 @@ void req_rdytocommit(
     {
     /* reply failed, purge the job and close the connection */
 
-    sprintf(log_buffer, "cannot report jobid - errno=%d - %s",
-            errno,
-            strerror(errno));
+    snprintf(log_buffer, sizeof(log_buffer),
+      "cannot report jobid - errno=%d - %s",
+      errno,
+      strerror(errno));
 
     log_err(errno, id, log_buffer);
 
@@ -1700,11 +1865,12 @@ void req_commit(
 
   /* need to format message first, before request goes away */
 
-  sprintf(log_buffer, msg_jobnew,
-          preq->rq_user, preq->rq_host,
-          pj->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
-          pj->ji_wattr[(int)JOB_ATR_jobname].at_val.at_str,
-          pj->ji_qhdr->qu_qs.qu_name);
+  snprintf(log_buffer, sizeof(log_buffer),
+    msg_jobnew,
+    preq->rq_user, preq->rq_host,
+    pj->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+    pj->ji_wattr[(int)JOB_ATR_jobname].at_val.at_str,
+    pj->ji_qhdr->qu_qs.qu_name);
 
   /* acknowledge the request with the job id */
 
@@ -1739,8 +1905,10 @@ void req_commit(
     {
     if (LOGLEVEL >= 7)
       {
-      sprintf(log_buffer, "Trying to AUTORUN job %s",
-              pj->ji_qs.ji_jobid);
+      snprintf(log_buffer, sizeof(log_buffer),
+        "Trying to AUTORUN job %s",
+        pj->ji_qs.ji_jobid);
+
       log_record(
         PBSEVENT_JOB,
         PBS_EVENTCLASS_JOB,
