@@ -724,6 +724,14 @@ nextjob:
  
   reply_send(preq);
 
+  if (LOGLEVEL >= 7)
+    {
+    log_event(PBSEVENT_SYSTEM,
+      PBS_EVENTCLASS_JOB,
+      "req_statjob",
+      "Successfully returned the status of queued jobs\n");
+    }
+
   return;
   }  /* END req_stat_job_step2() */
 
@@ -885,13 +893,6 @@ static void stat_update(
           }
 #endif    /* USESAVEDRESOURCES */
 
-#ifdef USESAVEDRESOURCES
-        else
-          {
-          /* save so we can recover resources used */
-          job_save(pjob, SAVEJOB_FULL);
-          }
-#endif    /* USESAVEDRESOURCES */
 
         pjob->ji_momstat = time_now;
         }
