@@ -150,6 +150,7 @@ extern tlist_head svr_queues;
 extern int    comp_resc_lt;
 extern int    comp_resc_gt;
 extern int    svr_do_schedule;
+extern int    listener_command;
 extern int    LOGLEVEL;
 
 extern time_t time_now;
@@ -164,6 +165,7 @@ extern int  svr_clnodes;
 extern int node_avail_complex(char *, int *, int *, int *, int *);
 extern int procs_available(int proc_ct);
 extern int procs_requested(char *spec);
+extern int remove_procct(job *);
 
 
 /* Private Functions */
@@ -530,6 +532,7 @@ int svr_enquejob(
       
     /* notify the scheduler we have a new job */
     svr_do_schedule = SCH_SCHEDULE_NEW;
+    listener_command = SCH_SCHEDULE_NEW;
     }
   else if (pque->qu_qs.qu_type == QTYPE_RoutePush)
     {
@@ -642,6 +645,7 @@ void svr_dequejob(
   /* notify scheduler a job has been removed */
 
   svr_do_schedule = SCH_SCHEDULE_TERM;
+  listener_command = SCH_SCHEDULE_TERM;
 
   return;
   }  /* END svr_dequejob() */
@@ -717,6 +721,7 @@ int svr_setjobstate(
             (newstate == JOB_STATE_QUEUED))
           {
           svr_do_schedule = SCH_SCHEDULE_NEW;
+          listener_command = SCH_SCHEDULE_NEW;
 
           if ((pjob->ji_wattr[JOB_ATR_etime].at_flags & ATR_VFLAG_SET) == 0)
             {
@@ -1532,7 +1537,7 @@ int svr_chkque(
 
   /*
    * 1. If the queue is an Execution queue ...
-   *    These is checked first because 1a - 1c are more damaging
+   *    This is checked first because 1a - 1c are more damaging
    *    (see local_move() in svr_movejob.c)
    */
 
@@ -1549,7 +1554,7 @@ int svr_chkque(
         }
       }
 
-    /* 1b. check site restrictions */
+    /* 1b. check site restrictions -- Currently site_acl_check is a stub */
 
     if (site_acl_check(pjob, pque))
       {
@@ -1739,7 +1744,7 @@ int svr_chkque(
 
         pas = pque->qu_attr[QA_ATR_AclGroup].at_val.at_arst;
 
-        for (i = 0;i < pas->as_usedptr;i++)
+        for (i = 0; pas != NULL && i < pas->as_usedptr;i++)
           {
           if ((grp = getgrnam(pas->as_string[i])) == NULL)
             continue;
@@ -2146,6 +2151,21 @@ static void default_std(
 
 #endif
 
+  if (*pd == '[')
+    {
+    pd++;
+
+    if (isdigit(*pd))
+      {
+      *(to + len++) = '-';
+
+      while (isdigit(*pd))
+        {
+        *(to + len++) = *pd++;
+        }
+      }
+    }
+
   *(to + len) = '\0';
 
   return;
@@ -2380,11 +2400,12 @@ void set_resc_deflt(
   attribute *ji_wattr) /* I (optional) decoded attributes  */
 
   {
-  attribute *ja;
+  attribute     *ja;
 
-  pbs_queue *pque;
+  pbs_queue     *pque;
   attribute_def *pdef;
-  int i, rc;
+  int            i;
+  int            rc;
 
   pque = pjob->ji_qhdr;
 
@@ -2408,7 +2429,7 @@ void set_resc_deflt(
 
 #ifdef RESOURCEMAXDEFAULT
   set_deflt_resc(ja, &pque->qu_attr[QA_ATR_ResourceMax]);
-
+/* http://www.adaptivecomputing.com/resources/docs/torque/4.2high-availability.php */
   /* server max limits will only be applied to attributes which have
      not yet been set */
 
@@ -2430,6 +2451,12 @@ void set_resc_deflt(
         }
       }
     }
+  
+  if (pque->qu_qs.qu_type == QTYPE_Execution)
+    {
+    /* unset the procct resource if it has been set */
+    remove_procct(pjob);
+    }
 
   return;
   }  /* END set_resc_deflt() */
